@@ -285,7 +285,7 @@ class BasicConfiguration(Configuration, SentryConfigurationMixin, MailConfigurat
         else:
             return values.PathValue(
                 default=os.path.join(self.BASE_DIR, 'static'),
-                environ_name='STATIC_ROOT',
+                environ_name='STATIC_ROOT_DIRECTORY',
                 environ_prefix='KRYNEGGER',
                 check_exists=False,
             )
@@ -522,18 +522,18 @@ class Development(BasicConfiguration):
         super(Development, cls).post_setup()
         logging.debug("done setting up! \o/")
 
-        sentry_sdk.init(
-            dsn="https://fe6ac3e9757f4c6fbb82aca586a9c285@sentry.io/3744204",
-            integrations=[
-                DjangoIntegration(),
-                CeleryIntegration(),
-                RedisIntegration()
-            ],
-
-            # If you wish to associate users to errors (assuming you are using
-            # django.contrib.auth) you may enable sending PII data.
-            send_default_pii=True
-        )
+        # sentry_sdk.init(
+        #     dsn=cls.SENTRY_DSN_URL.value,
+        #     integrations=[
+        #         DjangoIntegration(),
+        #         CeleryIntegration(),
+        #         RedisIntegration()
+        #     ],
+        #
+        #     # If you wish to associate users to errors (assuming you are using
+        #     # django.contrib.auth) you may enable sending PII data.
+        #     send_default_pii=True
+        # )
 
 class Staging(BasicConfiguration):
     """
@@ -594,6 +594,13 @@ class Production(Staging):
     """
     DEBUG = False
 
+    def STATIC_ROOT(self):
+        return values.PathValue(
+            environ_name='STATIC_ROOT_DIRECTORY',
+            environ_prefix='KRYNEGGER',
+            check_exists=True,
+        )
+
     @classmethod
     def pre_setup(cls):
         super(Production, cls).pre_setup()
@@ -618,4 +625,5 @@ class Production(Staging):
             # If you wish to associate users to errors (assuming you are using
             # django.contrib.auth) you may enable sending PII data.
             send_default_pii=True
-        )
\ No newline at end of file
+        )
+
